Crate iceoryx2_bb_linux

Crate iceoryx2_bb_linux 

Modules

epoll
Epoll is a safe abstraction over the event file descriptor in linux. It allows users to attach FileDescriptors with a set of EventTypes and InputFlags. Additionally, Epoll can also handle FetchableSignals via a wakeup and informing the user what FetchableSignal was raised.
signalfd
The SignalFd is a safe abstraction over the linux signal fd api. It allows users to receive a FetchableSignal via a FileDescriptor that can be attached to a FileDescriptorSet or via Epoll.