pub enum EpollCreateError {
PerProcessFileHandleLimitReached,
SystemWideFileHandleLimitReached,
InsufficientMemory,
SysCallReturnedInvalidFileDescriptor,
UnableToEnableSignalHandling,
UnknownError(i32),
}Expand description
Errors that can occur when EpollBuilder::create() creates a new Epoll.
Variants
PerProcessFileHandleLimitReached
The process file handle limit has been reached.
SystemWideFileHandleLimitReached
The system wide file handle limit has been reached.
InsufficientMemory
The system has not enough memory to create the Epoll
SysCallReturnedInvalidFileDescriptor
The syscall linux::epoll_create() returned a broken FileDescriptor.
UnableToEnableSignalHandling
EpollBuilder was configured to handle some FetchableSignals but the underlying
SignalFd could not be created.
UnknownError(i32)
An error occurred that was not described in the linux man-page.