EpollGetCapacityError

Enum EpollGetCapacityError 

pub enum EpollGetCapacityError {
    ProcFileDoesNotExist,
    ProcFileReadFailure,
    InsufficientPermissions,
    InsufficientMemory,
    PerProcessFileHandleLimitReached,
    SystemWideFileHandleLimitReached,
    Interrupt,
    InvalidProcFileContent,
    UnknownError,
}
Can be emitted by Epoll::capacity() when the epoll capacity is read from the proc file system.

Variants



ProcFileDoesNotExist

The proc file containing the capacity does not exist.



ProcFileReadFailure

The content of the proc file could not be read.



InsufficientPermissions

The process does not have the permission to open the proc file for reading.



InsufficientMemory

Insufficient memory to read from the proc file.



PerProcessFileHandleLimitReached

The process file handle limit has been reached.



SystemWideFileHandleLimitReached

The system wide file handle limit has been reached.



Interrupt

FetchableSignal::Interrupt was received (SIGINT).



InvalidProcFileContent

The proc file does not contain a number but something else.



UnknownError

An undocumented error occurred.