Modules
- epoll
Epollis a safe abstraction over the event file descriptor in linux. It allows users to attachFileDescriptors with a set ofEventTypes andInputFlags. Additionally,Epollcan also handleFetchableSignals via a wakeup and informing the user whatFetchableSignalwas raised.- signalfd
- The
SignalFdis a safe abstraction over the linux signal fd api. It allows users to receive aFetchableSignalvia aFileDescriptorthat can be attached to aFileDescriptorSetor viaEpoll.