#[repr(u32)]pub enum InputFlag {
EdgeTriggeredNotification = 2_147_483_648,
OneShotNotification = 1_073_741_824,
BlockSuspension = 536_870_912,
ExclusiveWakeup = 268_435_456,
}Expand description
The input flags for the FileDescriptor attachments.
Variants
EdgeTriggeredNotification = 2_147_483_648
Use edge triggered notifications instead of level triggered notifications.
See man epoll for more details.
OneShotNotification = 1_073_741_824
Enable one-shot notification for the attached FileDescriptor. If the state changed
the user is notified once in the wait calls. The user must detach and reattach the
FileDescriptor to rearm it again.
BlockSuspension = 536_870_912
Ensures that the system does not enter “suspend” or “hibernate” while this event is pending or being processed.
ExclusiveWakeup = 268_435_456
Sets an exclusive wakeup mode for the FileDescriptor. Useful when multiple epoll
file descriptors are attached to the same target file.